.. _introduction-index:

Getting started
===============

.. toctree::
   :maxdepth: 1

   overview
   installation
   tutorial
   blitz-tutorial
    
.. seealso::

    If you're new to Django_ and Python_, you may want to read up about them. A useful starting guide is in the `Django documentation`_.

    .. _python: http://python.org/
    .. _django: http://www.djangoproject.com/
    .. _django documentation: http://docs.djangoproject.com/en/dev/intro/
